<?php
namespace App\Http\Controllers;

use SimpleSoftwareIO\QrCode\Facades\QrCode;
use Illuminate\Http\Request;
use App\Models\LocalRegistration;
use Illuminate\Support\Facades\Storage;
use Intervention\Image\Facades\Image;

class FormController extends Controller
{
    // Show the form with countries
    public function showForm()
    {
        // Static data for countries and states
        $countries = [
            'USA' => [
                'California', 'Texas', 'New York', 'Florida', 'Illinois', 'Pennsylvania', 'Ohio', 'Georgia', 
                'North Carolina', 'Michigan', 'New Jersey', 'Virginia', 'Washington', 'Arizona', 'Massachusetts', 
                'Tennessee', 'Indiana', 'Missouri', 'Maryland', 'Wisconsin', 'Colorado', 'Minnesota', 'South Carolina', 
                'Alabama', 'Louisiana', 'Kentucky', 'Oregon', 'Oklahoma', 'Connecticut', 'Iowa', 'Mississippi', 'Arkansas'
            ],
            'Canada' => [
                'Ontario', 'Quebec', 'British Columbia', 'Alberta', 'Manitoba', 'Saskatchewan', 'Nova Scotia', 
                'New Brunswick', 'Prince Edward Island', 'Newfoundland and Labrador', 'Yukon', 'Northwest Territories', 'Nunavut'
            ],
            'India' => [
                'Delhi', 'Maharashtra', 'Karnataka', 'Tamil Nadu', 'Uttar Pradesh', 'West Bengal', 'Andhra Pradesh', 
                'Bihar', 'Rajasthan', 'Gujarat', 'Madhya Pradesh', 'Odisha', 'Chhattisgarh', 'Haryana', 'Telangana', 
                'Kerala', 'Jharkhand', 'Assam', 'Punjab', 'Himachal Pradesh', 'Chandigarh', 'Goa', 'Uttarakhand', 'Tripura'
            ],
            'Australia' => [
                'New South Wales', 'Queensland', 'Victoria', 'Western Australia', 'South Australia', 'Tasmania', 
                'Australian Capital Territory', 'Northern Territory'
            ],
            'United Kingdom' => [
                'England', 'Scotland', 'Wales', 'Northern Ireland'
            ],
            'Germany' => [
                'Bavaria', 'Berlin', 'Hamburg', 'Hesse', 'North Rhine-Westphalia', 'Saxony', 'Baden-Württemberg', 
                'Lower Saxony', 'Rhineland-Palatinate', 'Brandenburg', 'Mecklenburg-Vorpommern', 'Saarland', 
                'Thuringia', 'Schleswig-Holstein', 'Bremen'
            ],
            'France' => [
                'Île-de-France', 'Provence-Alpes-Côte d\'Azur', 'Normandy', 'Brittany', 'Aquitaine', 'Languedoc-Roussillon', 
                'Rhône-Alpes', 'Pays de la Loire', 'Loire Valley', 'Corsica', 'Alsace', 'Lorraine', 'Centre-Val de Loire'
            ],
            'Brazil' => [
                'São Paulo', 'Rio de Janeiro', 'Minas Gerais', 'Bahia', 'Rio Grande do Sul', 'Paraná', 'Pernambuco', 
                'Ceará', 'Pará', 'Santa Catarina', 'Maranhão', 'Goiás', 'Espírito Santo', 'Amazonas', 'Mato Grosso', 
                'Distrito Federal', 'Piauí', 'Amapá', 'Alagoas', 'Rondônia', 'Roraima', 'Tocantins', 'Sergipe', 'Mato Grosso do Sul'
            ],
            'South Africa' => [
                'Gauteng', 'KwaZulu-Natal', 'Western Cape', 'Eastern Cape', 'Mpumalanga', 'Limpopo', 'Free State', 
                'North West', 'Northern Cape'
            ],
            'Mexico' => [
                'Chihuahua', 'Jalisco', 'Nuevo León', 'Puebla', 'Mexico City', 'Guerrero', 'Sonora', 'Veracruz', 
                'Baja California', 'Yucatán', 'Oaxaca', 'Coahuila', 'Durango', 'Zacatecas', 'San Luis Potosí', 'Sinaloa', 
                'Chiapas', 'Quintana Roo', 'Hidalgo', 'Tlaxcala', 'Nayarit', 'Tabasco', 'Aguascalientes', 'Michoacán', 
                'Morelos', 'Colima', 'Campeche', 'Guanajuato', 'Querétaro', 'La Laguna'
            ],
            'Italy' => [
                'Lazio', 'Lombardy', 'Sicily', 'Campania', 'Veneto', 'Emilia-Romagna', 'Piedmont', 'Tuscany', 'Apulia', 
                'Calabria', 'Liguria', 'Marche', 'Abruzzo', 'Sardinia', 'Umbria', 'Friuli Venezia Giulia', 'Trentino-Alto Adige', 
                'Molise', 'Basilicata', 'Aosta Valley'
            ],
            'Spain' => [
                'Madrid', 'Catalonia', 'Andalusia', 'Valencia', 'Galicia', 'Castile and León', 'Basque Country', 
                'Castilla-La Mancha', 'Canary Islands', 'Murcia', 'Aragon', 'Extremadura', 'Balearic Islands', 'Asturias', 
                'Cantabria', 'La Rioja', 'Navarre', 'Melilla', 'Ceuta'
            ],
            'Japan' => [
                'Tokyo', 'Osaka', 'Kanagawa', 'Aichi', 'Saitama', 'Chiba', 'Hokkaido', 'Fukuoka', 'Hyogo', 'Kochi', 
                'Hiroshima', 'Shizuoka', 'Kyoto', 'Fukushima', 'Niigata', 'Gifu', 'Mie', 'Okinawa', 'Ibaraki', 'Tochigi', 
                'Yamagata', 'Shiga', 'Nagasaki', 'Yamaguchi'
            ],
            'Russia' => [
                'Moscow', 'Saint Petersburg', 'Tatarstan', 'Chelyabinsk', 'Samara', 'Sverdlovsk', 'Nizhny Novgorod', 
                'Krasnoyarsk', 'Omsk', 'Rostov', 'Khabarovsk', 'Primorsky Krai', 'Irkutsk', 'Volgograd', 'Tula', 'Vladimir', 
                'Ulyanovsk', 'Astrakhan', 'Voronezh', 'Kaluga', 'Kursk', 'Perm', 'Saratov', 'Kemerovo'
            ],
            'China' => [
                'Beijing', 'Shanghai', 'Guangdong', 'Shandong', 'Zhejiang', 'Jiangsu', 'Henan', 'Hunan', 'Sichuan', 
                'Liaoning', 'Anhui', 'Fujian', 'Hebei', 'Jiangxi', 'Hubei', 'Chongqing', 'Tianjin', 'Inner Mongolia', 
                'Xinjiang', 'Xizang (Tibet)', 'Ningxia', 'Guizhou', 'Yunnan', 'Hainan', 'Gansu', 'Qinghai', 'Jilin'
            ],
            'Argentina' => [
                'Buenos Aires', 'Córdoba', 'Santa Fe', 'Mendoza', 'Tucumán', 'Entre Ríos', 'Salta', 'Chaco', 'San Juan', 
                'Misiones', 'Formosa', 'Neuquén', 'Rio Negro', 'Chubut', 'Santa Cruz', 'La Pampa', 'Santiago del Estero', 
                'Corrientes', 'Catamarca', 'La Rioja', 'San Luis', 'Tierra del Fuego'
            ],
            'Nigeria' => [
                'Lagos', 'Kano', 'Rivers', 'Abuja', 'Oyo', 'Kaduna', 'Enugu', 'Anambra', 'Bauchi', 'Benue', 'Kogi', 
                'Jigawa', 'Imo', 'Taraba', 'Ekiti', 'Adamawa', 'Yobe', 'Zamfara', 'Ekiti', 'Ebonyi', 'Osun', 'Kwara', 
                'Delta', 'Ondo', 'Borno'
            ],
            'Egypt' => [
                'Cairo', 'Alexandria', 'Giza', 'Sharqia', 'Dakahlia', 'Beheira', 'Kalyubia', 'Menofia', 'Aswan', 
                'Fayoum', 'Qalyubia', 'Port Said', 'Red Sea', 'Suez', 'Luxor', 'Asyut', 'Gharbia', 'Damietta'
            ],
            'Turkey' => [
                'Istanbul', 'Ankara', 'Izmir', 'Bursa', 'Antalya', 'Adana', 'Konya', 'Gaziantep', 'Mersin', 'Şanlıurfa', 
                'Diyarbakır', 'Kayseri', 'Samsun', 'Trabzon', 'Mardin', 'Kocaeli', 'Balıkesir', 'Eskişehir', 'Aydın', 
                'Denizli', 'Bolu', 'Tekirdağ', 'Mugla', 'Manisa', 'Çorum'
            ]
        ];
        

        return view('local-entries', compact('countries'));
    }

    // Fetch states based on country
    public function getStates($country)
    {
        // Static data for states by country
        $states = [
            'USA' => [
                'California', 'Texas', 'New York', 'Florida', 'Illinois', 'Pennsylvania', 'Ohio', 'Georgia', 
                'North Carolina', 'Michigan', 'New Jersey', 'Virginia', 'Washington', 'Arizona', 'Massachusetts', 
                'Tennessee', 'Indiana', 'Missouri', 'Maryland', 'Wisconsin', 'Colorado', 'Minnesota', 'South Carolina', 
                'Alabama', 'Louisiana', 'Kentucky', 'Oregon', 'Oklahoma', 'Connecticut', 'Iowa', 'Mississippi', 'Arkansas'
            ],
            'Canada' => [
                'Ontario', 'Quebec', 'British Columbia', 'Alberta', 'Manitoba', 'Saskatchewan', 'Nova Scotia', 
                'New Brunswick', 'Prince Edward Island', 'Newfoundland and Labrador', 'Yukon', 'Northwest Territories', 'Nunavut'
            ],
            'India' => [
                'Delhi', 'Maharashtra', 'Karnataka', 'Tamil Nadu', 'Uttar Pradesh', 'West Bengal', 'Andhra Pradesh', 
                'Bihar', 'Rajasthan', 'Gujarat', 'Madhya Pradesh', 'Odisha', 'Chhattisgarh', 'Haryana', 'Telangana', 
                'Kerala', 'Jharkhand', 'Assam', 'Punjab', 'Himachal Pradesh', 'Chandigarh', 'Goa', 'Uttarakhand', 'Tripura'
            ],
            'Australia' => [
                'New South Wales', 'Queensland', 'Victoria', 'Western Australia', 'South Australia', 'Tasmania', 
                'Australian Capital Territory', 'Northern Territory'
            ],
            'United Kingdom' => [
                'England', 'Scotland', 'Wales', 'Northern Ireland'
            ],
            'Germany' => [
                'Bavaria', 'Berlin', 'Hamburg', 'Hesse', 'North Rhine-Westphalia', 'Saxony', 'Baden-Württemberg', 
                'Lower Saxony', 'Rhineland-Palatinate', 'Brandenburg', 'Mecklenburg-Vorpommern', 'Saarland', 
                'Thuringia', 'Schleswig-Holstein', 'Bremen'
            ],
            'France' => [
                'Île-de-France', 'Provence-Alpes-Côte d\'Azur', 'Normandy', 'Brittany', 'Aquitaine', 'Languedoc-Roussillon', 
                'Rhône-Alpes', 'Pays de la Loire', 'Loire Valley', 'Corsica', 'Alsace', 'Lorraine', 'Centre-Val de Loire'
            ],
            'Brazil' => [
                'São Paulo', 'Rio de Janeiro', 'Minas Gerais', 'Bahia', 'Rio Grande do Sul', 'Paraná', 'Pernambuco', 
                'Ceará', 'Pará', 'Santa Catarina', 'Maranhão', 'Goiás', 'Espírito Santo', 'Amazonas', 'Mato Grosso', 
                'Distrito Federal', 'Piauí', 'Amapá', 'Alagoas', 'Rondônia', 'Roraima', 'Tocantins', 'Sergipe', 'Mato Grosso do Sul'
            ],
            'South Africa' => [
                'Gauteng', 'KwaZulu-Natal', 'Western Cape', 'Eastern Cape', 'Mpumalanga', 'Limpopo', 'Free State', 
                'North West', 'Northern Cape'
            ],
            'Mexico' => [
                'Chihuahua', 'Jalisco', 'Nuevo León', 'Puebla', 'Mexico City', 'Guerrero', 'Sonora', 'Veracruz', 
                'Baja California', 'Yucatán', 'Oaxaca', 'Coahuila', 'Durango', 'Zacatecas', 'San Luis Potosí', 'Sinaloa', 
                'Chiapas', 'Quintana Roo', 'Hidalgo', 'Tlaxcala', 'Nayarit', 'Tabasco', 'Aguascalientes', 'Michoacán', 
                'Morelos', 'Colima', 'Campeche', 'Guanajuato', 'Querétaro', 'La Laguna'
            ],
            'Italy' => [
                'Lazio', 'Lombardy', 'Sicily', 'Campania', 'Veneto', 'Emilia-Romagna', 'Piedmont', 'Tuscany', 'Apulia', 
                'Calabria', 'Liguria', 'Marche', 'Abruzzo', 'Sardinia', 'Umbria', 'Friuli Venezia Giulia', 'Trentino-Alto Adige', 
                'Molise', 'Basilicata', 'Aosta Valley'
            ],
            'Spain' => [
                'Madrid', 'Catalonia', 'Andalusia', 'Valencia', 'Galicia', 'Castile and León', 'Basque Country', 
                'Castilla-La Mancha', 'Canary Islands', 'Murcia', 'Aragon', 'Extremadura', 'Balearic Islands', 'Asturias', 
                'Cantabria', 'La Rioja', 'Navarre', 'Melilla', 'Ceuta'
            ],
            'Japan' => [
                'Tokyo', 'Osaka', 'Kanagawa', 'Aichi', 'Saitama', 'Chiba', 'Hokkaido', 'Fukuoka', 'Hyogo', 'Kochi', 
                'Hiroshima', 'Shizuoka', 'Kyoto', 'Fukushima', 'Niigata', 'Gifu', 'Mie', 'Okinawa', 'Ibaraki', 'Tochigi', 
                'Yamagata', 'Shiga', 'Nagasaki', 'Yamaguchi'
            ],
            'Russia' => [
                'Moscow', 'Saint Petersburg', 'Tatarstan', 'Chelyabinsk', 'Samara', 'Sverdlovsk', 'Nizhny Novgorod', 
                'Krasnoyarsk', 'Omsk', 'Rostov', 'Khabarovsk', 'Primorsky Krai', 'Irkutsk', 'Volgograd', 'Tula', 'Vladimir', 
                'Ulyanovsk', 'Astrakhan', 'Voronezh', 'Kaluga', 'Kursk', 'Perm', 'Saratov', 'Kemerovo'
            ],
            'China' => [
                'Beijing', 'Shanghai', 'Guangdong', 'Shandong', 'Zhejiang', 'Jiangsu', 'Henan', 'Hunan', 'Sichuan', 
                'Liaoning', 'Anhui', 'Fujian', 'Hebei', 'Jiangxi', 'Hubei', 'Chongqing', 'Tianjin', 'Inner Mongolia', 
                'Xinjiang', 'Xizang (Tibet)', 'Ningxia', 'Guizhou', 'Yunnan', 'Hainan', 'Gansu', 'Qinghai', 'Jilin'
            ],
            'Argentina' => [
                'Buenos Aires', 'Córdoba', 'Santa Fe', 'Mendoza', 'Tucumán', 'Entre Ríos', 'Salta', 'Chaco', 'San Juan', 
                'Misiones', 'Formosa', 'Neuquén', 'Rio Negro', 'Chubut', 'Santa Cruz', 'La Pampa', 'Santiago del Estero', 
                'Corrientes', 'Catamarca', 'La Rioja', 'San Luis', 'Tierra del Fuego'
            ],
            'Nigeria' => [
                'Lagos', 'Kano', 'Rivers', 'Abuja', 'Oyo', 'Kaduna', 'Enugu', 'Anambra', 'Bauchi', 'Benue', 'Kogi', 
                'Jigawa', 'Imo', 'Taraba', 'Ekiti', 'Adamawa', 'Yobe', 'Zamfara', 'Ekiti', 'Ebonyi', 'Osun', 'Kwara', 
                'Delta', 'Ondo', 'Borno'
            ],
            'Egypt' => [
                'Cairo', 'Alexandria', 'Giza', 'Sharqia', 'Dakahlia', 'Beheira', 'Kalyubia', 'Menofia', 'Aswan', 
                'Fayoum', 'Qalyubia', 'Port Said', 'Red Sea', 'Suez', 'Luxor', 'Asyut', 'Gharbia', 'Damietta'
            ],
            'Turkey' => [
                'Istanbul', 'Ankara', 'Izmir', 'Bursa', 'Antalya', 'Adana', 'Konya', 'Gaziantep', 'Mersin', 'Şanlıurfa', 
                'Diyarbakır', 'Kayseri', 'Samsun', 'Trabzon', 'Mardin', 'Kocaeli', 'Balıkesir', 'Eskişehir', 'Aydın', 
                'Denizli', 'Bolu', 'Tekirdağ', 'Mugla', 'Manisa', 'Çorum'
            ]
        ];
        return response()->json($states[$country] ?? []);
    }
    public function saveEntry(Request $request)
    {
        $data = LocalRegistration::create([
            'name' => $request->input('name'),
            'company_name' => $request->input('company_name') ,
            'email' => $request->input('email'),
            'country' => $request->input('country'),
            'state' => $request->input('state'),
            'country_code' => $request->input('country_code'),
            'phone' => $request->input('country_code') . $request->input('phone'),
            'city' => $request->input('city'),
        ]);
        // Get the QR code data from the request
        $code = 'OM-' . str_pad($data->id, 5, '0', STR_PAD_LEFT);
        $qrCode = QrCode::size(250)
        ->generate($code . '|' . $request->input('company_name') . ',' . $request->input('name') . ',' . $request->input('state') . ',' . $request->input('city'));
        // Return the view with the generated QR code
        $countries = [
            'USA' => [
                'California', 'Texas', 'New York', 'Florida', 'Illinois', 'Pennsylvania', 'Ohio', 'Georgia', 
                'North Carolina', 'Michigan', 'New Jersey', 'Virginia', 'Washington', 'Arizona', 'Massachusetts', 
                'Tennessee', 'Indiana', 'Missouri', 'Maryland', 'Wisconsin', 'Colorado', 'Minnesota', 'South Carolina', 
                'Alabama', 'Louisiana', 'Kentucky', 'Oregon', 'Oklahoma', 'Connecticut', 'Iowa', 'Mississippi', 'Arkansas'
            ],
            'Canada' => [
                'Ontario', 'Quebec', 'British Columbia', 'Alberta', 'Manitoba', 'Saskatchewan', 'Nova Scotia', 
                'New Brunswick', 'Prince Edward Island', 'Newfoundland and Labrador', 'Yukon', 'Northwest Territories', 'Nunavut'
            ],
            'India' => [
                'Delhi', 'Maharashtra', 'Karnataka', 'Tamil Nadu', 'Uttar Pradesh', 'West Bengal', 'Andhra Pradesh', 
                'Bihar', 'Rajasthan', 'Gujarat', 'Madhya Pradesh', 'Odisha', 'Chhattisgarh', 'Haryana', 'Telangana', 
                'Kerala', 'Jharkhand', 'Assam', 'Punjab', 'Himachal Pradesh', 'Chandigarh', 'Goa', 'Uttarakhand', 'Tripura'
            ],
            'Australia' => [
                'New South Wales', 'Queensland', 'Victoria', 'Western Australia', 'South Australia', 'Tasmania', 
                'Australian Capital Territory', 'Northern Territory'
            ],
            'United Kingdom' => [
                'England', 'Scotland', 'Wales', 'Northern Ireland'
            ],
            'Germany' => [
                'Bavaria', 'Berlin', 'Hamburg', 'Hesse', 'North Rhine-Westphalia', 'Saxony', 'Baden-Württemberg', 
                'Lower Saxony', 'Rhineland-Palatinate', 'Brandenburg', 'Mecklenburg-Vorpommern', 'Saarland', 
                'Thuringia', 'Schleswig-Holstein', 'Bremen'
            ],
            'France' => [
                'Île-de-France', 'Provence-Alpes-Côte d\'Azur', 'Normandy', 'Brittany', 'Aquitaine', 'Languedoc-Roussillon', 
                'Rhône-Alpes', 'Pays de la Loire', 'Loire Valley', 'Corsica', 'Alsace', 'Lorraine', 'Centre-Val de Loire'
            ],
            'Brazil' => [
                'São Paulo', 'Rio de Janeiro', 'Minas Gerais', 'Bahia', 'Rio Grande do Sul', 'Paraná', 'Pernambuco', 
                'Ceará', 'Pará', 'Santa Catarina', 'Maranhão', 'Goiás', 'Espírito Santo', 'Amazonas', 'Mato Grosso', 
                'Distrito Federal', 'Piauí', 'Amapá', 'Alagoas', 'Rondônia', 'Roraima', 'Tocantins', 'Sergipe', 'Mato Grosso do Sul'
            ],
            'South Africa' => [
                'Gauteng', 'KwaZulu-Natal', 'Western Cape', 'Eastern Cape', 'Mpumalanga', 'Limpopo', 'Free State', 
                'North West', 'Northern Cape'
            ],
            'Mexico' => [
                'Chihuahua', 'Jalisco', 'Nuevo León', 'Puebla', 'Mexico City', 'Guerrero', 'Sonora', 'Veracruz', 
                'Baja California', 'Yucatán', 'Oaxaca', 'Coahuila', 'Durango', 'Zacatecas', 'San Luis Potosí', 'Sinaloa', 
                'Chiapas', 'Quintana Roo', 'Hidalgo', 'Tlaxcala', 'Nayarit', 'Tabasco', 'Aguascalientes', 'Michoacán', 
                'Morelos', 'Colima', 'Campeche', 'Guanajuato', 'Querétaro', 'La Laguna'
            ],
            'Italy' => [
                'Lazio', 'Lombardy', 'Sicily', 'Campania', 'Veneto', 'Emilia-Romagna', 'Piedmont', 'Tuscany', 'Apulia', 
                'Calabria', 'Liguria', 'Marche', 'Abruzzo', 'Sardinia', 'Umbria', 'Friuli Venezia Giulia', 'Trentino-Alto Adige', 
                'Molise', 'Basilicata', 'Aosta Valley'
            ],
            'Spain' => [
                'Madrid', 'Catalonia', 'Andalusia', 'Valencia', 'Galicia', 'Castile and León', 'Basque Country', 
                'Castilla-La Mancha', 'Canary Islands', 'Murcia', 'Aragon', 'Extremadura', 'Balearic Islands', 'Asturias', 
                'Cantabria', 'La Rioja', 'Navarre', 'Melilla', 'Ceuta'
            ],
            'Japan' => [
                'Tokyo', 'Osaka', 'Kanagawa', 'Aichi', 'Saitama', 'Chiba', 'Hokkaido', 'Fukuoka', 'Hyogo', 'Kochi', 
                'Hiroshima', 'Shizuoka', 'Kyoto', 'Fukushima', 'Niigata', 'Gifu', 'Mie', 'Okinawa', 'Ibaraki', 'Tochigi', 
                'Yamagata', 'Shiga', 'Nagasaki', 'Yamaguchi'
            ],
            'Russia' => [
                'Moscow', 'Saint Petersburg', 'Tatarstan', 'Chelyabinsk', 'Samara', 'Sverdlovsk', 'Nizhny Novgorod', 
                'Krasnoyarsk', 'Omsk', 'Rostov', 'Khabarovsk', 'Primorsky Krai', 'Irkutsk', 'Volgograd', 'Tula', 'Vladimir', 
                'Ulyanovsk', 'Astrakhan', 'Voronezh', 'Kaluga', 'Kursk', 'Perm', 'Saratov', 'Kemerovo'
            ],
            'China' => [
                'Beijing', 'Shanghai', 'Guangdong', 'Shandong', 'Zhejiang', 'Jiangsu', 'Henan', 'Hunan', 'Sichuan', 
                'Liaoning', 'Anhui', 'Fujian', 'Hebei', 'Jiangxi', 'Hubei', 'Chongqing', 'Tianjin', 'Inner Mongolia', 
                'Xinjiang', 'Xizang (Tibet)', 'Ningxia', 'Guizhou', 'Yunnan', 'Hainan', 'Gansu', 'Qinghai', 'Jilin'
            ],
            'Argentina' => [
                'Buenos Aires', 'Córdoba', 'Santa Fe', 'Mendoza', 'Tucumán', 'Entre Ríos', 'Salta', 'Chaco', 'San Juan', 
                'Misiones', 'Formosa', 'Neuquén', 'Rio Negro', 'Chubut', 'Santa Cruz', 'La Pampa', 'Santiago del Estero', 
                'Corrientes', 'Catamarca', 'La Rioja', 'San Luis', 'Tierra del Fuego'
            ],
            'Nigeria' => [
                'Lagos', 'Kano', 'Rivers', 'Abuja', 'Oyo', 'Kaduna', 'Enugu', 'Anambra', 'Bauchi', 'Benue', 'Kogi', 
                'Jigawa', 'Imo', 'Taraba', 'Ekiti', 'Adamawa', 'Yobe', 'Zamfara', 'Ekiti', 'Ebonyi', 'Osun', 'Kwara', 
                'Delta', 'Ondo', 'Borno'
            ],
            'Egypt' => [
                'Cairo', 'Alexandria', 'Giza', 'Sharqia', 'Dakahlia', 'Beheira', 'Kalyubia', 'Menofia', 'Aswan', 
                'Fayoum', 'Qalyubia', 'Port Said', 'Red Sea', 'Suez', 'Luxor', 'Asyut', 'Gharbia', 'Damietta'
            ],
            'Turkey' => [
                'Istanbul', 'Ankara', 'Izmir', 'Bursa', 'Antalya', 'Adana', 'Konya', 'Gaziantep', 'Mersin', 'Şanlıurfa', 
                'Diyarbakır', 'Kayseri', 'Samsun', 'Trabzon', 'Mardin', 'Kocaeli', 'Balıkesir', 'Eskişehir', 'Aydın', 
                'Denizli', 'Bolu', 'Tekirdağ', 'Mugla', 'Manisa', 'Çorum'
            ]
        ];
        return view('qrCode', compact('countries','qrCode'));
    }
}
